Update language to comply with Android’s inclusive language guidance

See https://source.android.com/setup/contribute/respectful-code for reference

Bug: 161896447
Test: tapas LatinIME && m
Change-Id: Ic06f948c023a091e1532db826a78dd01031d7205
diff --git a/native/jni/src/dictionary/utils/binary_dictionary_shortcut_iterator.h b/native/jni/src/dictionary/utils/binary_dictionary_shortcut_iterator.h
index 3638f38..45c9cd3 100644
--- a/native/jni/src/dictionary/utils/binary_dictionary_shortcut_iterator.h
+++ b/native/jni/src/dictionary/utils/binary_dictionary_shortcut_iterator.h
@@ -41,12 +41,12 @@
     }
 
     // Gets the shortcut target itself as an int string and put it to outTarget, put its length
     // to outTargetLength, put whether it is allowlist to outIsWhitelist.
     AK_FORCE_INLINE void nextShortcutTarget(
             const int maxDepth, int *const outTarget, int *const outTargetLength,
-            bool *const outIsWhitelist) {
+            bool *const outIsAllowed) {
         mShortcutStructurePolicy->getNextShortcut(maxDepth, outTarget, outTargetLength,
-                outIsWhitelist, &mHasNextShortcutTarget, &mPos);
+                outIsAllowed, &mHasNextShortcutTarget, &mPos);
     }
 
  private:
@@ -41,12 +41,12 @@
 
     // Gets the shortcut target itself as an int string and put it to outTarget, put its length
-    // to outTargetLength, put whether it is allowlist to outIsWhitelist.
+    // to outTargetLength, put whether it is allowlist to outIsAllowed.
     AK_FORCE_INLINE void nextShortcutTarget(
             const int maxDepth, int *const outTarget, int *const outTargetLength,